.. image:: https://img.shields.io/badge/assist-v1.0.0-green.svg?style=flat
    :target: https://assist.readthedocs.org

ASSIST
======

ASSIST is a package supporting high-accuracy ephemeric calculations for small Solar System bodies in REBOUND.
